pub struct ProgressState {
pub current_step: Option<String>,
pub completed: bool,
pub history: Vec<String>,
}Expand description
Progress tracking state for flows.
Fields
current_step: Option<String>completed: boolhistory: Vec<String>Trait Implementations
Sourceimpl Clone for ProgressState
impl Clone for ProgressState
Sourcefn clone(&self) -> ProgressState
fn clone(&self) -> ProgressState
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProgressState
impl Debug for ProgressState
Sourceimpl<'de> Deserialize<'de> for ProgressState
impl<'de> Deserialize<'de> for ProgressState
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ProgressState
impl JsonSchema for ProgressState
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProgressState
impl PartialEq for ProgressState
Sourceimpl Serialize for ProgressState
impl Serialize for ProgressState
impl StructuralPartialEq for ProgressState