pub struct ValidationError {
pub question_id: Option<String>,
pub path: Option<String>,
pub message: String,
pub code: Option<String>,
}Expand description
Validation error metadata reported by the engine.
Fields
question_id: Option<String>path: Option<String>message: Stringcode: Option<String>Trait Implementations
Sourceimpl Clone for ValidationError
impl Clone for ValidationError
Sourcefn clone(&self) -> ValidationError
fn clone(&self) -> ValidationError
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ValidationError
impl Debug for ValidationError
Sourceimpl<'de> Deserialize<'de> for ValidationError
impl<'de> Deserialize<'de> for ValidationError
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ValidationError
impl JsonSchema for ValidationError
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ValidationError
impl PartialEq for ValidationError
Sourceimpl Serialize for ValidationError
impl Serialize for ValidationError
impl StructuralPartialEq for ValidationError