pub struct ValidationResult {
pub valid: bool,
pub errors: Vec<ValidationError>,
pub missing_required: Vec<String>,
pub unknown_fields: Vec<String>,
}Expand description
Result returned from validate_answers.
Fields
valid: boolerrors: Vec<ValidationError>missing_required: Vec<String>unknown_fields: Vec<String>Trait Implementations
Sourceimpl Clone for ValidationResult
impl Clone for ValidationResult
Sourcefn clone(&self) -> ValidationResult
fn clone(&self) -> ValidationResult
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ValidationResult
impl Debug for ValidationResult
Sourceimpl<'de> Deserialize<'de> for ValidationResult
impl<'de> Deserialize<'de> for ValidationResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ValidationResult
impl JsonSchema for ValidationResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ValidationResult
impl PartialEq for ValidationResult
Sourceimpl Serialize for ValidationResult
impl Serialize for ValidationResult
impl StructuralPartialEq for ValidationResult