Functions
- apply_
computed_ answers - Applies computed expressions defined in the spec and returns a new answer map that includes the derived values.
- build_
expression_ context - Builds a context used by expressions so answers can be addressed via question ids and the special
answerskey.