pub struct I18nText {
pub key: String,
pub args: Option<BTreeMap<String, Value>>,
}Expand description
i18n text descriptor used by form/question display fields.
Fields
key: Stringargs: Option<BTreeMap<String, Value>>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for I18nText
impl<'de> Deserialize<'de> for I18nText
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for I18nText
impl JsonSchema for I18nText
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for I18nText