Structs
- Render
Payload - Collected payload used by both text and JSON renderers.
- Render
Progress - Progress counters exposed to renderers.
- Render
Question - Describes a single question for render outputs.
Enums
- Render
Status - Status labels returned by the renderers.
Functions
- build_
render_ payload - Build the renderer payload from the specification, context, and answers.
- build_
render_ payload_ with_ i18n - Build the renderer payload from the specification, context, and answers with optional i18n map.
- render_
card - Render the payload as an Adaptive Card v1.3 transport.
- render_
json_ ui - Render the payload as a structured JSON-friendly value.
- render_
text - Render the payload as human-friendly text.