pub fn build_render_payload(
spec: &FormSpec,
ctx: &Value,
answers: &Value,
) -> RenderPayloadExpand description
Build the renderer payload from the specification, context, and answers.
pub fn build_render_payload(
spec: &FormSpec,
ctx: &Value,
answers: &Value,
) -> RenderPayloadBuild the renderer payload from the specification, context, and answers.