Module runner

Module runner 

Structs

QaPlanV1
Versioned deterministic plan produced by runner planning functions.

Functions

execute_plan_effects
Executes plan effects into the provided store context value.
normalize_answers
Canonicalize incoming answers into an object payload.
plan_next
Build a deterministic next-step plan for the current answers/context.
plan_submit_all
Build a deterministic plan for submit-all without applying side effects.
plan_submit_patch
Build a deterministic plan for patch submission without applying side effects.