pub struct DecisionCase {
pub if_expr: Expr,
pub goto: StepId,
}Expand description
Conditional branch case.
Fields
if_expr: Exprgoto: StepIdTrait Implementations
Sourceimpl Clone for DecisionCase
impl Clone for DecisionCase
Sourcefn clone(&self) -> DecisionCase
fn clone(&self) -> DecisionCase
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DecisionCase
impl Debug for DecisionCase
Sourceimpl<'de> Deserialize<'de> for DecisionCase
impl<'de> Deserialize<'de> for DecisionCase
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DecisionCase
impl JsonSchema for DecisionCase
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DecisionCase
impl PartialEq for DecisionCase
Sourceimpl Serialize for DecisionCase
impl Serialize for DecisionCase
impl StructuralPartialEq for DecisionCase