pub struct DecisionStep {
pub cases: Vec<DecisionCase>,
pub default_goto: Option<StepId>,
}Expand description
Decision / branching step.
Fields
cases: Vec<DecisionCase>default_goto: Option<StepId>Trait Implementations
Sourceimpl Clone for DecisionStep
impl Clone for DecisionStep
Sourcefn clone(&self) -> DecisionStep
fn clone(&self) -> DecisionStep
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for DecisionStep
impl Debug for DecisionStep
Sourceimpl<'de> Deserialize<'de> for DecisionStep
impl<'de> Deserialize<'de> for DecisionStep
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DecisionStep
impl JsonSchema for DecisionStep
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for DecisionStep
impl PartialEq for DecisionStep
Sourceimpl Serialize for DecisionStep
impl Serialize for DecisionStep
impl StructuralPartialEq for DecisionStep