pub struct FlowPolicy {
pub allow_back: bool,
pub allow_submit_all: bool,
}Expand description
Flow-wide policies (placeholder for future expansion).
Fields
allow_back: boolallow_submit_all: boolTrait Implementations
Sourceimpl Clone for FlowPolicy
impl Clone for FlowPolicy
Sourcefn clone(&self) -> FlowPolicy
fn clone(&self) -> FlowPolicy
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FlowPolicy
impl Debug for FlowPolicy
Sourceimpl<'de> Deserialize<'de> for FlowPolicy
impl<'de> Deserialize<'de> for FlowPolicy
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FlowPolicy
impl JsonSchema for FlowPolicy
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for FlowPolicy
impl PartialEq for FlowPolicy
Sourceimpl Serialize for FlowPolicy
impl Serialize for FlowPolicy
impl StructuralPartialEq for FlowPolicy