pub struct MessageStep {
pub mode: CardMode,
pub template: String,
pub next: Option<StepId>,
}Expand description
Single message/prompt step inside a flow.
Fields
mode: CardModetemplate: Stringnext: Option<StepId>Trait Implementations
Sourceimpl Clone for MessageStep
impl Clone for MessageStep
Sourcefn clone(&self) -> MessageStep
fn clone(&self) -> MessageStep
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MessageStep
impl Debug for MessageStep
Sourceimpl<'de> Deserialize<'de> for MessageStep
impl<'de> Deserialize<'de> for MessageStep
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MessageStep
impl JsonSchema for MessageStep
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for MessageStep
impl PartialEq for MessageStep
Sourceimpl Serialize for MessageStep
impl Serialize for MessageStep
impl StructuralPartialEq for MessageStep