pub struct QAFlowSpec {
pub id: String,
pub title: String,
pub version: String,
pub entry: StepId,
pub steps: BTreeMap<StepId, StepSpec>,
pub policies: Option<FlowPolicy>,
}Expand description
QAFlow: directed graph of steps executed inside the wizard.
Fields
id: Stringtitle: Stringversion: Stringentry: StepIdsteps: BTreeMap<StepId, StepSpec>policies: Option<FlowPolicy>Trait Implementations
Sourceimpl Clone for QAFlowSpec
impl Clone for QAFlowSpec
Sourcefn clone(&self) -> QAFlowSpec
fn clone(&self) -> QAFlowSpec
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for QAFlowSpec
impl Debug for QAFlowSpec
Sourceimpl<'de> Deserialize<'de> for QAFlowSpec
impl<'de> Deserialize<'de> for QAFlowSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for QAFlowSpec
impl JsonSchema for QAFlowSpec
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for QAFlowSpec
impl PartialEq for QAFlowSpec
Sourceimpl Serialize for QAFlowSpec
impl Serialize for QAFlowSpec
impl StructuralPartialEq for QAFlowSpec