pub struct QuestionStep {
pub question_id: String,
pub next: Option<StepId>,
}Expand description
Step that asks a question.
Fields
question_id: Stringnext: Option<StepId>Trait Implementations
Sourceimpl Clone for QuestionStep
impl Clone for QuestionStep
Sourcefn clone(&self) -> QuestionStep
fn clone(&self) -> QuestionStep
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for QuestionStep
impl Debug for QuestionStep
Sourceimpl<'de> Deserialize<'de> for QuestionStep
impl<'de> Deserialize<'de> for QuestionStep
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for QuestionStep
impl JsonSchema for QuestionStep
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for QuestionStep
impl PartialEq for QuestionStep
Sourceimpl Serialize for QuestionStep
impl Serialize for QuestionStep
impl StructuralPartialEq for QuestionStep