pub struct FormPresentation {
pub intro: Option<String>,
pub theme: Option<String>,
pub default_locale: Option<String>,
}Expand description
Presentation hints for a form.
Fields
intro: Option<String>theme: Option<String>default_locale: Option<String>Trait Implementations
Sourceimpl Clone for FormPresentation
impl Clone for FormPresentation
Sourcefn clone(&self) -> FormPresentation
fn clone(&self) -> FormPresentation
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FormPresentation
impl Debug for FormPresentation
Sourceimpl<'de> Deserialize<'de> for FormPresentation
impl<'de> Deserialize<'de> for FormPresentation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FormPresentation
impl JsonSchema for FormPresentation
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for FormPresentation
impl PartialEq for FormPresentation
Sourceimpl Serialize for FormPresentation
impl Serialize for FormPresentation
impl StructuralPartialEq for FormPresentation