pub struct FormSpec {
pub id: String,
pub title: String,
pub version: String,
pub description: Option<String>,
pub presentation: Option<FormPresentation>,
pub progress_policy: Option<ProgressPolicy>,
pub secrets_policy: Option<SecretsPolicy>,
pub store: Vec<StoreOp>,
pub validations: Vec<CrossFieldValidation>,
pub questions: Vec<QuestionSpec>,
}Expand description
Top-level QA form definition.
Fields
id: Stringtitle: Stringversion: Stringdescription: Option<String>presentation: Option<FormPresentation>progress_policy: Option<ProgressPolicy>secrets_policy: Option<SecretsPolicy>store: Vec<StoreOp>validations: Vec<CrossFieldValidation>questions: Vec<QuestionSpec>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for FormSpec
impl<'de> Deserialize<'de> for FormSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for FormSpec
impl JsonSchema for FormSpec
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for FormSpec