pub struct IncludeSpec {
pub form_ref: String,
pub prefix: Option<String>,
}Expand description
Include reference for composing forms from a registry.
Fields
form_ref: Stringprefix: Option<String>Trait Implementations
Sourceimpl Clone for IncludeSpec
impl Clone for IncludeSpec
Sourcefn clone(&self) -> IncludeSpec
fn clone(&self) -> IncludeSpec
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IncludeSpec
impl Debug for IncludeSpec
Sourceimpl<'de> Deserialize<'de> for IncludeSpec
impl<'de> Deserialize<'de> for IncludeSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for IncludeSpec
impl JsonSchema for IncludeSpec
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for IncludeSpec
impl PartialEq for IncludeSpec
Sourceimpl Serialize for IncludeSpec
impl Serialize for IncludeSpec
impl StructuralPartialEq for IncludeSpec