pub struct ProgressPolicy {
pub skip_answered: bool,
pub autofill_defaults: bool,
pub treat_default_as_answered: bool,
}Expand description
Execution policies shared by question navigation.
Fields
skip_answered: boolautofill_defaults: booltreat_default_as_answered: boolTrait Implementations
Sourceimpl Clone for ProgressPolicy
impl Clone for ProgressPolicy
Sourcefn clone(&self) -> ProgressPolicy
fn clone(&self) -> ProgressPolicy
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ProgressPolicy
impl Debug for ProgressPolicy
Sourceimpl Default for ProgressPolicy
impl Default for ProgressPolicy
Sourceimpl<'de> Deserialize<'de> for ProgressPolicy
impl<'de> Deserialize<'de> for ProgressPolicy
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ProgressPolicy
impl JsonSchema for ProgressPolicy
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ProgressPolicy
impl PartialEq for ProgressPolicy
Sourceimpl Serialize for ProgressPolicy
impl Serialize for ProgressPolicy
impl Copy for ProgressPolicy
impl StructuralPartialEq for ProgressPolicy