pub struct SecretsPolicy {
pub enabled: bool,
pub read_enabled: bool,
pub write_enabled: bool,
pub allow: Vec<String>,
pub deny: Vec<String>,
}Expand description
Secrets policy for the form.
Fields
enabled: boolread_enabled: boolwrite_enabled: boolallow: Vec<String>deny: Vec<String>Trait Implementations
Sourceimpl Clone for SecretsPolicy
impl Clone for SecretsPolicy
Sourcefn clone(&self) -> SecretsPolicy
fn clone(&self) -> SecretsPolicy
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SecretsPolicy
impl Debug for SecretsPolicy
Sourceimpl<'de> Deserialize<'de> for SecretsPolicy
impl<'de> Deserialize<'de> for SecretsPolicy
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for SecretsPolicy
impl JsonSchema for SecretsPolicy
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SecretsPolicy
impl PartialEq for SecretsPolicy
Sourceimpl Serialize for SecretsPolicy
impl Serialize for SecretsPolicy
impl StructuralPartialEq for SecretsPolicy