pub struct Constraint {
pub pattern: Option<String>,
pub min: Option<f64>,
pub max: Option<f64>,
pub min_len: Option<usize>,
pub max_len: Option<usize>,
}Expand description
Constraints that can be enforced per question.
Fields
pattern: Option<String>min: Option<f64>max: Option<f64>min_len: Option<usize>max_len: Option<usize>Trait Implementations
Sourceimpl Clone for Constraint
impl Clone for Constraint
Sourcefn clone(&self) -> Constraint
fn clone(&self) -> Constraint
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for Constraint
impl Debug for Constraint
Sourceimpl<'de> Deserialize<'de> for Constraint
impl<'de> Deserialize<'de> for Constraint
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Constraint
impl JsonSchema for Constraint
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for Constraint
impl PartialEq for Constraint
Sourceimpl Serialize for Constraint
impl Serialize for Constraint
impl StructuralPartialEq for Constraint