pub struct ListSpec {
pub min_items: Option<usize>,
pub max_items: Option<usize>,
pub fields: Vec<QuestionSpec>,
}Expand description
Definition of a repeatable list whose entries reuse question definitions.
Fields
min_items: Option<usize>max_items: Option<usize>fields: Vec<QuestionSpec>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for ListSpec
impl<'de> Deserialize<'de> for ListSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ListSpec
impl JsonSchema for ListSpec
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for ListSpec