pub struct QuestionSpec {Show 16 fields
pub id: String,
pub kind: QuestionType,
pub title: String,
pub title_i18n: Option<I18nText>,
pub description: Option<String>,
pub description_i18n: Option<I18nText>,
pub required: bool,
pub choices: Option<Vec<String>>,
pub default_value: Option<String>,
pub secret: bool,
pub visible_if: Option<Expr>,
pub constraint: Option<Constraint>,
pub list: Option<ListSpec>,
pub computed: Option<Expr>,
pub policy: QuestionPolicy,
pub computed_overridable: bool,
}Expand description
Definition of a single question inside a form.
Fields
id: Stringkind: QuestionTypetitle: Stringtitle_i18n: Option<I18nText>description: Option<String>description_i18n: Option<I18nText>required: boolchoices: Option<Vec<String>>default_value: Option<String>secret: boolvisible_if: Option<Expr>constraint: Option<Constraint>list: Option<ListSpec>computed: Option<Expr>policy: QuestionPolicycomputed_overridable: boolTrait Implementations
Sourceimpl Clone for QuestionSpec
impl Clone for QuestionSpec
Sourcefn clone(&self) -> QuestionSpec
fn clone(&self) -> QuestionSpec
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for QuestionSpec
impl Debug for QuestionSpec
Sourceimpl<'de> Deserialize<'de> for QuestionSpec
impl<'de> Deserialize<'de> for QuestionSpec
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for QuestionSpec
impl JsonSchema for QuestionSpec
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for QuestionSpec
impl PartialEq for QuestionSpec
Sourceimpl Serialize for QuestionSpec
impl Serialize for QuestionSpec
impl StructuralPartialEq for QuestionSpec