pub struct CrossFieldValidation {
pub id: Option<String>,
pub message: String,
pub fields: Vec<String>,
pub condition: Expr,
pub code: Option<String>,
}Expand description
Cross-question validation rules expressed as reusable conditions.
Fields
id: Option<String>message: Stringfields: Vec<String>condition: Exprcode: Option<String>Trait Implementations
Sourceimpl Clone for CrossFieldValidation
impl Clone for CrossFieldValidation
Sourcefn clone(&self) -> CrossFieldValidation
fn clone(&self) -> CrossFieldValidation
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CrossFieldValidation
impl Debug for CrossFieldValidation
Sourceimpl<'de> Deserialize<'de> for CrossFieldValidation
impl<'de> Deserialize<'de> for CrossFieldValidation
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CrossFieldValidation
impl JsonSchema for CrossFieldValidation
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CrossFieldValidation
impl PartialEq for CrossFieldValidation
Sourceimpl Serialize for CrossFieldValidation
impl Serialize for CrossFieldValidation
impl StructuralPartialEq for CrossFieldValidation