Module computed

Module computed 

Functions

apply_computed_answers
Applies computed expressions defined in the spec and returns a new answer map that includes the derived values.
build_expression_context
Builds a context used by expressions so answers can be addressed via question ids and the special answers key.